PasswordRequirements

Struct PasswordRequirements 

pub struct PasswordRequirements {
    pub length: u16,
    pub decimal: u16,
    pub specials: u16,
    pub first_is_letter: bool,
    pub allow_repeats: bool,
}
A structure to describe password requirements.

Fields

length: u16

The length of the password.

decimal: u16

How many decimal integer characters should the password contain?

specials: u16

How many special characters should the password contain?

first_is_letter: bool

Should the first character always be a letter?

allow_repeats: bool

Allow characters to be used more than once?

Implementations

Source

impl PasswordRequirements

pub fn validate(&self) -> Self

Validates the instance’s values.

This returns a mutated copy of the instance where the values satisfy “sane minimum requirements” suitable for any password.

The phrase “sane minimum requirements” implies

  1. length is not less than 10

  2. To avoid repetitions, length is not more than

    • 52 if only letters (no decimal integers or special characters) are used
    • 62 if only letters and decimal integers are used
    • 68 if only letters and special characters are used
    • 78 if letters, decimal integers, and special characters are used
    • u16::MAX if repeated characters are allowed
  3. specials character count does not overrule the required number of

    • letters (2; 1 uppercase and 1 lowercase)
    • decimal integers (if decimal is specified as non-zero value)
  4. decimal character count does not overrule the required number of

    • letters (2; 1 uppercase and 1 lowercase)
    • special characters (if specials is specified as non-zero value)
About resolving conflicts

If this function finds a conflict between the specified number of specials characters and decimal, then decimal integers takes precedence.

For example:

use mk_pass::PasswordRequirements;
let req = PasswordRequirements {
    length: 16,
    specials: 16,
    decimal: 16,
    ..Default::default()
};
let expected = PasswordRequirements {
    length: 16,
    specials: 1,
    decimal: 13,
    ..Default::default()
};
assert_eq!(req.validate(), expected);